@@ -1,5 +1,5 @@
 import React from 'react'
-import {ScreensSchema} from 'system/types'
+import {ScreensSchema} from 'system/screens'
 
 
 export const screensSchema: ScreensSchema = {
